@@ -2,12 +2,12 @@
 use strict;
 use warnings;
 
-use Net::Frame::IPv4;
-use Net::Frame::TCP;
+use Net::Frame::Layer::IPv4;
+use Net::Frame::Layer::TCP;
 use Net::Frame::Simple;
 
-my $ip4 = Net::Frame::IPv4->new;
-my $tcp = Net::Frame::TCP->new(
+my $ip4 = Net::Frame::Layer::IPv4->new;
+my $tcp = Net::Frame::Layer::TCP->new(
    options => "\x02\x04\x54\x0b",
    payload => 'test',
 );
